@@ -1,4 +1,4 @@
-with_mock_dir("httptest2/record", {
+with_mock_dir("t/record", {
   test_that("cong_record works", {
     x <- cong_record()
     expect_s3_class(x, 'tbl_df')
